pub struct OutputErrors {
pub id: FHIRId,
pub version_id: FHIRId,
pub resource_type: FHIRCode,
pub fhir_method: FHIRCode,
pub sequence: FHIRInteger,
pub attempt_count: FHIRInteger,
pub error_message: FHIRString,
pub first_failed_at: FHIRDateTime,
pub last_failed_at: FHIRDateTime,
pub resolved_at: Option<FHIRDateTime>,
}Fields
id: FHIRIdVersion id of the resource that failed to index.
version_id: FHIRIdVersion id of the resource that failed to index.
resource_type: FHIRCodeFHIR resource type of the resource that failed to index.
fhir_method: FHIRCodeThe operation (create, update or delete) that failed to index.
sequence: FHIRIntegerSequence position of the resource in the indexing stream.
attempt_count: FHIRIntegerNumber of times indexing has been attempted for this resource.
error_message: FHIRStringThe error that occurred while indexing.
first_failed_at: FHIRDateTimeWhen this resource first failed indexing.
last_failed_at: FHIRDateTimeWhen this resource most recently failed indexing.
resolved_at: Option<FHIRDateTime>When this failure was marked resolved, if it has been.